==> chesstab-5.0.5.tar.gz: chesstab-5.0.5/chesstab/gui/repertoiredbshow.py <==
# repertoiredbshow.py
# Copyright 2013 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Customise show toplevel to display repertoire record.
"""

from solentware_grid.gui.datashow import DataShow

from solentware_misc.gui.exceptionhandler import ExceptionHandler

from pgn_read.core.parser import PGN

from ..core.constants import TAG_OPENING
from .repertoiretoplevel import RepertoireToplevel
from .toplevelpgn import ShowPGN


class RepertoireDbShow(ExceptionHandler, ShowPGN, DataShow):

    """Show PGN text for repertoire from database.

    parent is used as the master argument in a RepertoireToplevel call.

    ui is used as the ui argument in a RepertoireToplevel call.

    parent, oldobject, and the RepertoireToplevel instance created, are used as
    arguments in the super.__init__ call.

    Attribute pgn_score_name provides the name used in widget titles and
    message text.

    Methods get_title_for_object and set_item, and properties ui_base_table;
    ui_items_in_toplevels; and ui, allow similar methods in various classes
    to be expressed identically and defined once.

    """

    pgn_score_name = "Repertoire"

    def __init__(self, parent, oldobject, ui=None):
        """Extend and create toplevel widget for deleting chess repertoire."""
        # Toplevel title set '' in __init__ and to proper value in initialize.
        super().__init__(
            oldobject, parent, RepertoireToplevel(master=parent, ui=ui), ""
        )
        self.initialize()

    @property
    def ui_base_table(self):
        return self.ui.base_repertoires

    @property
    def ui_items_in_toplevels(self):
        return self.ui.games_and_repertoires_in_toplevels

    @property
    def ui(self):
        return self.oldview.ui

    def set_item(self, view, object_):
        self.set_default_source_for_object(object_)
        view.set_position_analysis_data_source()
        view.collected_game = next(
            PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
        )
        view.set_and_tag_item_text()

    def get_title_for_object(self, object_=None):
        """Return title for Toplevel containing a Repertoire object_.

        Default value of object_ is object attribute from DataShow class.

        """
        if object_ is None:
            object_ = self.object
        try:
            return "  ".join(
                (
                    self.pgn_score_name.join(("Show ", ":")),
                    object_.value.collected_game._tags[TAG_OPENING],
                )
            )
        except TypeError:
            return self.pgn_score_name.join(
                ("Show ", " - names unknown or invalid")
            )
        except KeyError:
            return self.pgn_score_name.join(
                ("Show ", " - names unknown or invalid")
            )

    def set_default_source_for_object(self, object_=None):
        """Set default source for Toplevel containing a Repertoire object_.

        Default value of object_ is object attribute from DataShow class.

        """
        pass

==> chesstab-6.0.tar.gz: chesstab-6.0/chesstab/gui/repertoiredbshow.py <==
# repertoiredbshow.py
# Copyright 2013 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Customise show toplevel to display repertoire record."""

from solentware_grid.gui.datashow import DataShow

from pgn_read.core.parser import PGN

from ..core.constants import TAG_OPENING
from .repertoiretoplevel import RepertoireToplevel
from .toplevelpgn import ShowPGNToplevel


class RepertoireDbShow(ShowPGNToplevel, DataShow):
    """Show PGN text for repertoire from database.

    parent is used as the master argument in a RepertoireToplevel call.

    ui is used as the ui argument in a RepertoireToplevel call.

    parent, oldobject, and the RepertoireToplevel instance created, are used as
    arguments in the super.__init__ call.

    Attribute pgn_score_name provides the name used in widget titles and
    message text.

    Methods _get_title_for_object and _set_item, and properties ui_base_table;
    ui_items_in_toplevels; and ui, allow similar methods in various classes
    to be expressed identically and defined once.

    """

    pgn_score_name = "Repertoire"

    def __init__(self, parent=None, oldobject=None, ui=None):
        """Extend and create toplevel widget for deleting chess repertoire."""
        # Toplevel title set '' in __init__ and to proper value in _initialize.
        super().__init__(
            instance=oldobject,
            parent=parent,
            oldview=RepertoireToplevel(master=parent, ui=ui),
            title="",
        )
        self._initialize()

    @property
    def ui_base_table(self):
        """Return the User Interface RepertoireGrid object."""
        return self.ui.base_repertoires

    @property
    def ui_items_in_toplevels(self):
        """Return the User Interface objects in Toplevels."""
        return self.ui.games_and_repertoires_in_toplevels

    @property
    def ui(self):
        """Return the User Interface object from 'read-only' view."""
        return self.oldview.ui

    def _set_item(self, view, object_):
        """Populate view with the repertoire extracted from object_."""
        self._set_default_source_for_object(object_)
        view.set_position_analysis_data_source()
        view.collected_game = next(
            PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
        )
        view.set_and_tag_item_text()

    def _get_title_for_object(self, object_=None):
        """Return title for Toplevel containing a Repertoire object_.

        Default value of object_ is object attribute from DataShow class.

        """
        if object_ is None:
            object_ = self.object
        try:
            return "  ".join(
                (
                    self.pgn_score_name.join(("Show ", ":")),
                    object_.value.collected_game.pgn_tags[TAG_OPENING],
                )
            )
        except TypeError:
            return self.pgn_score_name.join(
                ("Show ", " - names unknown or invalid")
            )
        except KeyError:
            return self.pgn_score_name.join(
                ("Show ", " - names unknown or invalid")
            )

    def _set_default_source_for_object(self, object_=None):
        """Set default source for Toplevel containing a Repertoire object_.

        Default value of object_ is object attribute from DataShow class.

        """
